@@ -1,7 +1,7 @@
 from discretize.tensor_mesh import TensorMesh
 from discretize.cylindrical_mesh import CylMesh, CylindricalMesh
 from discretize.curvilinear_mesh import CurvilinearMesh
-from discretize.base.mesh_io import load_mesh
+from discretize.utils.io_utils import load_mesh
 
 try:
     from discretize.tree_mesh import TreeMesh
@@ -28,7 +28,7 @@ except ImportError as err:
         )
 from discretize import tests
 
-__version__ = "0.6.2"
+__version__ = "0.7.0"
 __author__ = "SimPEG Team"
 __license__ = "MIT"
 __copyright__ = "2013, SimPEG Developers, http://simpeg.xyz"
