@@ -370,6 +370,7 @@ class InterfaceMPL(object):
         v_type="CC",
         normal="Z",
         ind=None,
+        slice_loc=None,
         grid=False,
         view="real",
         ax=None,
@@ -397,6 +398,8 @@ class InterfaceMPL(object):
             Normal direction of slicing plane.
         ind : None, optional
             index along dimension of slice. Defaults to the center index.
+        slice_loc : None, optional
+            Value along dimension of slice. Defaults to the center of the mesh.
         view : {'real', 'imag', 'abs', 'vec'}
             How to view the array.
         ax : matplotlib.axes.Axes, optional
@@ -424,14 +427,13 @@ class InterfaceMPL(object):
 
         Examples
         --------
-        Plot a slice of a 3D ``TensorMesh`` solution to a Laplace's equaiton.
+        Plot a slice of a 3D `TensorMesh` solution to a Laplace's equaiton.
 
         First build the mesh:
 
         >>> from matplotlib import pyplot as plt
         >>> import discretize
         >>> from pymatsolver import Solver
-        >>> import numpy as np
         >>> hx = [(5, 2, -1.3), (2, 4), (5, 2, 1.3)]
         >>> hy = [(2, 2, -1.3), (2, 6), (2, 2, 1.3)]
         >>> hz = [(2, 2, -1.3), (2, 6), (2, 2, 1.3)]
@@ -449,6 +451,45 @@ class InterfaceMPL(object):
 
         >>> M.plot_slice(M.cell_gradient*b, 'F', view='vec', grid=True, pcolor_opts={'alpha':0.8})
         >>> plt.show()
+
+        We can use the `slice_loc kwarg to tell `plot_slice` where to slice the mesh.
+        Let's create a mesh with a random model and plot slice of it. The `slice_loc`
+        kwarg automatically determines the indices for slicing the mesh along a plane with
+        the given normal.
+
+        >>> M = discretize.TensorMesh([32, 32, 32])
+        >>> v = discretize.utils.random_model(M.vnC, seed=789).reshape(-1, order='F')
+        >>> x_slice, y_slice, z_slice = 0.75, 0.25, 0.9
+        >>> plt.figure(figsize=(7.5, 3))
+        >>> ax = plt.subplot(131)
+        >>> M.plot_slice(v, normal='X', slice_loc=x_slice, ax=ax)
+        >>> ax = plt.subplot(132)
+        >>> M.plot_slice(v, normal='Y', slice_loc=y_slice, ax=ax)
+        >>> ax = plt.subplot(133)
+        >>> M.plot_slice(v, normal='Z', slice_loc=z_slice, ax=ax)
+        >>> plt.tight_layout()
+        >>> plt.show()
+
+        This also works for `TreeMesh`. We create a mesh here that is refined within three
+        boxes, along with a base level of refinement.
+
+        >>> TM = discretize.TreeMesh([32, 32, 32])
+        >>> TM.refine(3, finalize=False)
+        >>> BSW = [[0.25, 0.25, 0.25], [0.15, 0.15, 0.15], [0.1, 0.1, 0.1]]
+        >>> TNE = [[0.75, 0.75, 0.75], [0.85, 0.85, 0.85], [0.9, 0.9, 0.9]]
+        >>> levels = [6, 5, 4]
+        >>> TM.refine_box(BSW, TNE, levels)
+        >>> v_TM = discretize.utils.volume_average(M, TM, v)
+        >>> plt.figure(figsize=(7.5, 3))
+        >>> ax = plt.subplot(131)
+        >>> TM.plot_slice(v_TM, normal='X', slice_loc=x_slice, ax=ax)
+        >>> ax = plt.subplot(132)
+        >>> TM.plot_slice(v_TM, normal='Y', slice_loc=y_slice, ax=ax)
+        >>> ax = plt.subplot(133)
+        >>> TM.plot_slice(v_TM, normal='Z', slice_loc=z_slice, ax=ax)
+        >>> plt.tight_layout()
+        >>> plt.show()
+
         """
         mesh_type = self._meshType.lower()
         plotters = {
@@ -515,6 +556,7 @@ class InterfaceMPL(object):
                         v_type=v_typeI,
                         normal=normal,
                         ind=ind,
+                        slice_loc=slice_loc,
                         grid=grid,
                         view=view,
                         ax=ax,
@@ -528,6 +570,7 @@ class InterfaceMPL(object):
                     )
                 ]
             return out
+
         viewOpts = ["real", "imag", "abs", "vec"]
         normalOpts = ["X", "Y", "Z"]
         v_typeOpts = [
@@ -567,6 +610,18 @@ class InterfaceMPL(object):
         if self.dim == 2:
             raise NotImplementedError("Must be a 3D mesh. Use plotImage.")
 
+        # slice_loc errors
+        if (ind is not None) and (slice_loc is not None):
+            raise Warning("Both ind and slice_loc are defined. Behavior undefined.")
+        # slice_loc implement
+        if slice_loc is not None:
+            if normal == "X":
+                ind = int(np.argmin(np.abs(self.cell_centers_x - slice_loc)))
+            if normal == "Y":
+                ind = int(np.argmin(np.abs(self.cell_centers_y - slice_loc)))
+            if normal == "Z":
+                ind = int(np.argmin(np.abs(self.cell_centers_z - slice_loc)))
+
         if ax is None:
             plt.figure()
             ax = plt.subplot(111)
@@ -949,9 +1004,7 @@ class InterfaceMPL(object):
                     self.cell_centers_x, v, linestyle="-", color="C1", marker="o"
                 )
             elif v_type == "N":
-                ph = ax.plot(
-                    self.nodes_x, v, linestyle="-", color="C0", marker="s"
-                )
+                ph = ax.plot(self.nodes_x, v, linestyle="-", color="C0", marker="s")
             ax.set_xlabel("x")
             ax.axis("tight")
         elif self.dim == 2:
@@ -1887,34 +1940,44 @@ class InterfaceMPL(object):
         grid_opts=None,
         range_x=None,
         range_y=None,
+        quiver_opts=None,
         **kwargs,
     ):
         if self.dim == 3:
             raise NotImplementedError(
                 "plotImage is not implemented for 3D TreeMesh, please use plotSlice"
             )
-
-        if view == "vec":
-            raise NotImplementedError(
-                "Vector ploting is not supported on TreeMesh (yet)"
-            )
-
-        if view in ["real", "imag", "abs"]:
-            v = getattr(np, view)(v)  # e.g. np.real(v)
+        # reshape to cell_centered thing
         if v_type == "CC":
-            I = v
-        elif v_type == "N":
-            I = self.aveN2CC * v
+            pass
+        if v_type == "CCv":
+            if view != "vec":
+                raise ValueError("Other types for CCv not supported")
+        elif v_type in ["F", "E", "N"]:
+            aveOp = aveOp = "ave" + v_type + ("2CCV" if view == "vec" else "2CC")
+            v = getattr(self, aveOp) * v
+            if view == "vec":
+                v = v.reshape((self.n_cells, 2), order="F")
         elif v_type in ["Fx", "Fy", "Ex", "Ey"]:
             aveOp = "ave" + v_type[0] + "2CCV"
+            v = getattr(self, aveOp) * v
             ind_xy = {"x": 0, "y": 1}[v_type[1]]
-            I = (getattr(self, aveOp) * v).reshape(2, self.n_cells)[
-                ind_xy
-            ]  # average to cell centers
+            v = v.reshape(2, self.n_cells)[ind_xy]
+
+        if view in ["real", "imag", "abs"]:
+            I = getattr(np, view)(v)  # e.g. np.real(v)
+        elif view == "vec":
+            I = np.linalg.norm(v, axis=1)
+
+        isnot_nans = ~np.isnan(I)
 
         # pcolormesh call signature
         # def pcolormesh(self, *args, alpha=None, norm=None, cmap=None, vmin=None,
         #            vmax=None, shading='flat', antialiased=False, **kwargs):
+
+        # make a shallow copy so we can pop items off for the pass to PolyCollection
+        pcolor_opts = pcolor_opts.copy()
+
         alpha = pcolor_opts.pop("alpha", None)
         norm = pcolor_opts.pop("norm", None)
         cmap = pcolor_opts.pop("cmap", None)
@@ -1925,6 +1988,7 @@ class InterfaceMPL(object):
 
         node_grid = np.r_[self.nodes, self.hanging_nodes]
         cell_nodes = self.cell_nodes[:, (0, 1, 3, 2)]
+        cell_nodes = cell_nodes[isnot_nans]
         cell_verts = node_grid[cell_nodes]
 
         # Below taken from pcolormesh source code with QuadMesh exchanged to PolyCollection
@@ -1932,7 +1996,7 @@ class InterfaceMPL(object):
             cell_verts, antialiased=antialiased, **{**pcolor_opts, **grid_opts}
         )
         collection.set_alpha(alpha)
-        collection.set_array(I)
+        collection.set_array(I[isnot_nans])
         collection.set_cmap(cmap)
         collection.set_norm(norm)
         try:
@@ -1951,7 +2015,7 @@ class InterfaceMPL(object):
             minx, maxx = self.nodes_x[[0, -1]]
 
         if range_y is not None:
-            miny, maxy = range_x
+            miny, maxy = range_y
         else:
             miny, maxy = self.nodes_y[[0, -1]]
 
@@ -1961,7 +2025,26 @@ class InterfaceMPL(object):
         ax.update_datalim(corners)
         ax._request_autoscale_view()
 
-        return (collection,)
+        out = (collection,)
+
+        if view == "vec":
+            if quiver_opts is None:
+                quiver_opts = {}
+            # make a copy so we can set some defaults without modifying the original
+            quiver_opts = quiver_opts.copy()
+            quiver_opts.setdefault("pivot", "mid")
+
+            v = v.reshape(2, self.n_cells)
+            qvr = ax.quiver(
+                self.cell_centers[:, 0],
+                self.cell_centers[:, 1],
+                v[0],
+                v[1],
+                **quiver_opts,
+            )
+            out = (collection, qvr)
+
+        return out
 
     def __plot_slice_tree(
         self,
@@ -1977,12 +2060,9 @@ class InterfaceMPL(object):
         grid_opts=None,
         range_x=None,
         range_y=None,
+        quiver_opts=None,
         **kwargs,
     ):
-        if view == "vec":
-            raise NotImplementedError(
-                "Vector view plotting is not implemented for TreeMesh (yet)"
-            )
         normalInd = {"X": 0, "Y": 1, "Z": 2}[normal]
         antiNormalInd = {"X": [1, 2], "Y": [0, 2], "Z": [0, 1]}[normal]
 
@@ -2022,12 +2102,16 @@ class InterfaceMPL(object):
         tm_gridboost[:, antiNormalInd] = temp_mesh.gridCC
         tm_gridboost[:, normalInd] = slice_loc
 
-        # interpolate values to self.gridCC if not 'CC'
-        if v_type != "CC":
+        # interpolate values to self.gridCC if not "CC" or "CCv"
+        if v_type[:2] != "CC":
             aveOp = "ave" + v_type + "2CC"
+            if view == "vec":
+                aveOp += "V"
             Av = getattr(self, aveOp)
-            if v.size == Av.shape[1]:
+            if v.shape[0] == Av.shape[1]:
                 v = Av * v
+            if view == "vec":
+                v = v.reshape((self.n_cells, 3), order="F")
             elif len(v_type) == 2:
                 # was one of Fx, Fy, Fz, Ex, Ey, Ez
                 # assuming v has all three components in these cases
@@ -2038,6 +2122,14 @@ class InterfaceMPL(object):
                     i_s = np.cumsum([0, self.nFx, self.nFy, self.nFz])
                 v = v[i_s[vec_ind] : i_s[vec_ind + 1]]
                 v = Av * v
+        elif v_type == "CCv":
+            if view != "vec":
+                raise ValueError("Other types for CCv not supported")
+        slice_view = view
+        if view == "vec":
+            slice_view = "real"
+            vecs = v[:, antiNormalInd]
+            v = np.linalg.norm(v, axis=1)
 
         # interpolate values from self.gridCC to grid2d
         ind_3d_to_2d = self._get_containing_cell_indexes(tm_gridboost)
@@ -2047,7 +2139,7 @@ class InterfaceMPL(object):
             v2d,
             v_type="CC",
             grid=grid,
-            view=view,
+            view=slice_view,
             ax=ax,
             pcolor_opts=pcolor_opts,
             grid_opts=grid_opts,
@@ -2058,6 +2150,23 @@ class InterfaceMPL(object):
         ax.set_xlabel("y" if normal == "X" else "x")
         ax.set_ylabel("y" if normal == "Z" else "z")
         ax.set_title("Slice {0:d}, {1!s} = {2:4.2f}".format(ind, normal, slice_loc))
+
+        if view == "vec":
+            if quiver_opts is None:
+                quiver_opts = {}
+            # make a copy so we can set some defaults without modifying the original
+            quiver_opts = quiver_opts.copy()
+            quiver_opts.setdefault("pivot", "mid")
+            vecs = vecs[ind_3d_to_2d]
+            qvr = ax.quiver(
+                temp_mesh.cell_centers[:, 0],
+                temp_mesh.cell_centers[:, 1],
+                vecs[:, 0],
+                vecs[:, 1],
+                **quiver_opts,
+            )
+            out = (qvr,)
+
         return out
 
     plotGrid = deprecate_method("plot_grid", "plotGrid", removal_version="1.0.0")
